pub struct DownloadManager { /* private fields */ }Implementations
Sourceimpl DownloadManager
impl DownloadManager
pub fn new() -> Self
pub fn downloads(&self) -> SharedDownloads
Sourcepub fn save_data(&self, data: &[u8], filename: &str) -> Result<PathBuf>
pub fn save_data(&self, data: &[u8], filename: &str) -> Result<PathBuf>
Save arbitrary bytes as a file in the system Downloads directory. Returns the path to the saved file on success.
Sourcepub fn start_download(&self, url: String)
pub fn start_download(&self, url: String)
Kick off a background download for url. Returns immediately.
The file is saved into the system Downloads directory.
Sourcepub fn start_download_to(&self, url: String, dest_dir: &Path)
pub fn start_download_to(&self, url: String, dest_dir: &Path)
Kick off a background download for url into a specific directory.
Sourcepub fn cancel(&self, id: DownloadId)
pub fn cancel(&self, id: DownloadId)
Cancel an in-progress download.
Sourcepub fn dismiss(&self, id: DownloadId)
pub fn dismiss(&self, id: DownloadId)
Remove a finished (or cancelled/failed) download entry from the list.
pub fn has_active(&self) -> bool